Empfang — Lino Tera Benutzerhandbuch

# Empfang

- Patienten
  - Einen neuen Patienten erfassen
  - Datenfelder Patienten

## Erstgespräche

In der offenen Sprechstunde kann sich der potentielle Patient mit einem Therapeuten zu einem Erstgespräch treffen. Dort wird entschieden, bei welchem Therapeuten der Patient eine Therapie startet. Zu diesem Zeitpunkt existiert noch keine Akte.

Um einen Termin für ein Erstgespräch zu erstellen:

- erfasse den Patienten